@@ -17,7 +17,8 @@ class AuthUserViewSet(CustomModelViewSet):
     serializer_class = AuthUserSerializer
 
     def create(self, request, *args, **kwargs):
-        return self.model_class.objects.create_user(**request.data)
+        self.model_class.objects.create_user(**request.data)
+        return Response('success')
 
     @action(detail=False, methods=['get'], url_path='current', url_name='current')
     def current(self, request, *args, **kwargs):
