@@ -2,8 +2,8 @@ from bluedot_rest_framework.utils.serializers import CustomSerializer
 from rest_framework.serializers import CharField, IntegerField
 from bluedot_rest_framework import import_string
 
-EventComment = import_string('EVENT.comment.models')
-EventCommentLike = import_string('EVENT.comment.like_models')
+EventComment = import_string('event.comment.models')
+EventCommentLike = import_string('event.comment.like_models')
 
 
 class EventCommentSerializer(CustomSerializer):
