@@ -5,8 +5,8 @@ from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.func import orm_bulk_update
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet
 
-EventSchedule = import_string('EVENT.schedule.models')
-EventScheduleSerializer = import_string('EVENT.schedule.serializers')
+EventSchedule = import_string('event.schedule.models')
+EventScheduleSerializer = import_string('event.schedule.serializers')
 
 
 class EventScheduleView(CustomModelViewSet):
