@@ -42,7 +42,7 @@ class EventSpeakerView(CustomModelViewSet):
                 orm_bulk_update(speaker_queryset, speaker_data)
             else:
                 queryset = self.model_class.objects.create(
-                    description=item.get('description', ''), img=item.get('img', ''), jobs=item.get('job', ''), name=item.get('name', ''), sort=item['sort'], is_sign_page=item.get('is_sign_page', False), event_id=data['event_id'])
+                    description=item.get('description', ''), img=item.get('img', ''), job=item.get('job', ''), name=item.get('name', ''), sort=item['sort'], is_sign_page=item.get('is_sign_page', False), event_id=data['event_id'])
                 ids.append(str(queryset.pk))
         speaker_model = self.model_class.objects.exclude(id__in=ids)
         speaker_model.filter(event_id=data['event_id']).delete()
