@@ -4,6 +4,7 @@ from rest_framework import status
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.config.models import Config
 from bluedot_rest_framework.config.serializers import ConfigSerializer
+from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
 from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler, jwt_get_unionid_handler
 
@@ -60,6 +61,7 @@ class QuestionView(CustomModelViewSet, AllView):
 class QuestionUserView(CustomModelViewSet):
     model_class = QuestionUser
     serializer_class = QuestionUserSerializer
+    permission_classes = [IsAuthenticatedOrReadOnly]
 
     filterset_fields = {
         'unionid': {
@@ -93,7 +95,7 @@ class QuestionUserView(CustomModelViewSet):
                 for option_index, qa_option in enumerate(qa_item['option']):
                     rate_data = questionQueryset.qa[index]
                     if 'rate' not in rate_data:
-                        if qa_option['checked'] == 1:
+                        if 'checked' in qa_option and qa_option['checked'] == 1:
                             qa_option['rate'] = 1
                         else:
                             qa_option['rate'] = 0
@@ -117,7 +119,8 @@ class QuestionUserView(CustomModelViewSet):
                     qa_data = self.model_class.objects.filter(
                         qa_id=response_data['qa_id'])
                     for item in qa_data:
-                        if item.qa[index]['option'][option_index]['checked'] == 1:
+                        qa_checked = item.qa[index]['option'][option_index]
+                        if 'checked' in qa_checked and qa_checked['checked'] == 1:
                             count += 1
                     option_list.append(count)
 
