@@ -6,8 +6,8 @@ from django.conf import settings
 
 
 class AESEncrypt(object):
-    iv = settings.BLUEDOT_REST_FRAMEWORK['UTILS']['AES']['iv']
-    key = settings.BLUEDOT_REST_FRAMEWORK['UTILS']['AES']['key']
+    iv = settings.BLUEDOT_REST_FRAMEWORK['utils']['AES']['iv']
+    key = settings.BLUEDOT_REST_FRAMEWORK['utils']['AES']['key']
 
     def __init__(self):
         self.model = AES.MODE_CBC
