@@ -1,4 +1,5 @@
 from datetime import datetime
+from bluedot_rest_framework.utils.crypto import AESEncrypt
 
 
 class FilterBackend:
@@ -21,7 +22,15 @@ class FilterBackend:
                     elif key == 'area':
                         queryset = self.get_area(
                             field_value, filterset_fields, queryset)
-
+                    elif key == 'chinese_name':
+                        queryset = self.get_chinese_name(
+                            field_value, filterset_fields, queryset)
+                    elif key == 'english_name':
+                        queryset = self.get_english_name(
+                            field_value, filterset_fields, queryset)
+                    elif key == 'staff_num':
+                        queryset = self.get_staff_num(
+                            field_value, filterset_fields, queryset)
                     else:
                         _filter = filterset_fields[key]
                         if _filter['lookup_expr'] == '__in':
@@ -39,8 +48,22 @@ class FilterBackend:
         queryset = queryset.filter(category_id__contains=int(field_value))
         return queryset
 
+    def get_staff_num(self, field_value, filterset_field, queryset):
+        queryset = queryset.filter(
+            staff_num=AESEncrypt.encrypt(field_value))
+        return queryset
+
+    def get_chinese_name(self, field_value, filterset_field, queryset):
+        queryset = queryset.filter(
+            chinese_name=AESEncrypt.encrypt(field_value))
+        return queryset
+
+    def get_english_name(self, field_value, filterset_field, queryset):
+        queryset = queryset.filter(
+            english_name=AESEncrypt.encrypt(field_value))
+        return queryset
+
     def get_area(self, field_value, filterset_field, queryset):
-        print(field_value)
         area_dict = {
             'macau': '港澳特别行政区',
             'south': '南区',
