@@ -1,3 +1,6 @@
+import hashlib
+
+
 def get_tree(data, parent):
     result = []
     for item in data:
@@ -22,3 +25,9 @@ def orm_bulk_update(queryset, update_dict):
         for key in update_dict:
             setattr(queryset, key, update_dict[key])
         return queryset.save()
+
+
+def md5_str(_str):
+    md5_obj = hashlib.md5()
+    md5_obj.update(_str.encode('utf8'))
+    return md5_obj.hexdigest()
