@@ -35,6 +35,21 @@ class CustomModelViewSet(ModelViewSet):
         # },
     }
 
+    def create_update(self, request, queryset, *args, **kwargs):
+        if queryset:
+            partial = kwargs.pop('partial', False)
+            serializer = self.get_serializer(
+                queryset, data=request.data, partial=partial)
+            serializer.is_valid(raise_exception=True)
+            self.perform_update(serializer)
+            return Response(serializer.data)
+        else:
+            serializer = self.get_serializer(data=request.data)
+            serializer.is_valid(raise_exception=True)
+            self.perform_create(serializer)
+            headers = self.get_success_headers(serializer.data)
+            return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
+
     def get_queryset(self):
         queryset = self.model_class.objects.all()
         queryset = FilterBackend.get_filterset(
@@ -47,8 +62,8 @@ class CustomModelViewSet(ModelViewSet):
 
 
 def user_perform_create(token, serializer):
-    wechat_id, unionid ,userid= jwt_get_userinfo_handler(token)
-    serializer.save(unionid=unionid, wechat_id=wechat_id,userid=userid)
+    wechat_id, unionid, userid = jwt_get_userinfo_handler(token)
+    serializer.save(unionid=unionid, wechat_id=wechat_id, userid=userid)
 
 
 class TreeAPIView(ListAPIView):
