@@ -27,17 +27,17 @@ class WeChatUserSet:
                     'city': user_info.get('city', ''),
                     'country': user_info.get('country', ''),
                     'language': user_info.get('language', ''),
-                    
+
                 }
                 self.openid = user_info.get('openid', '')
-                unionid=self.user_data['unionid']
+                unionid = self.user_data['unionid']
                 if unionid == '':
                     wechat_queryset = WeChatUserOpenid.objects.filter(
-                    openid=self.openid).first()
+                        openid=self.openid).first()
                     if wechat_queryset:
-                        wechat_id=wechat_queryset.wechat_id
-                        self.wechat_user_queryset=WeChatUser.objects.filter(
-                        pk=wechat_id).first()
+                        wechat_id = wechat_queryset.wechat_id
+                        self.wechat_user_queryset = WeChatUser.objects.filter(
+                            pk=wechat_id).first()
                 else:
                     self.wechat_user_queryset = WeChatUser.objects.filter(
                         unionid=self.user_data['unionid']).first()
@@ -47,12 +47,12 @@ class WeChatUserSet:
                 try:
                     user_info = App(self.appid).user.get(self.openid)
                     self.__init__(appid=self.appid, user_info=user_info)
-                    unionid=self.user_data['unionid']
+                    unionid = self.user_data['unionid']
                     if unionid == '':
                         wechat_id = WeChatUserOpenid.objects.filter(
-                        openid=self.openid).first().wechat_id
-                        self.wechat_user_queryset=WeChatUser.objects.filter(
-                        wechat_id=wechat_id).first()
+                            openid=self.openid).first().wechat_id
+                        self.wechat_user_queryset = WeChatUser.objects.filter(
+                            wechat_id=wechat_id).first()
 
                     else:
                         self.wechat_user_queryset = WeChatUser.objects.filter(
@@ -65,8 +65,7 @@ class WeChatUserSet:
                         queryset = WeChatUser.objects.filter(
                             pk=wechat_user_openid_queryset.wechat_id).first()
                         if queryset:
-                            self.wechat_user_queryset = WeChatUser.objects.filter(
-                                unionid=queryset.unionid).first()
+                            self.wechat_user_queryset = queryset
                     pass
 
     def create_user(self):
@@ -94,7 +93,7 @@ class WeChatUserSet:
             self.update_user()
         else:
             self.create_user()
- 
+
     def get_token(self):
         token = ''
         if self.wechat_user_queryset:
